==> style-o-matic-1.1.3.tgz: package/es/components/Button/Button.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import { isModifiedEvent, isLeftClickEvent, CoreComponent, getPropTypesA11y, getPropDefaultsAutoId, getValidProps, getElementType, ROLE } from "../../lib";
import Dropdown from "../Dropdown/Dropdown.js";
import "./Button.css";

var Button = (_temp2 = _class = function (_CoreComponent) {
  _inherits(Button, _CoreComponent);

  function Button() {
    var _temp, _this, _ret;

    _classCallCheck(this, Button);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.handleClick = function (e) {
      if (_this.props.disabled) {
        return;
      }
      if (_this.props.onClick) {
        _this.props.onClick(e);
      }
      if (isModifiedEvent(e) || !isLeftClickEvent(e)) {
        return;
      }
      if (e.defaultPrevented === true) {
        return;
      }
      e.preventDefault();
    }, _this.handleKeyDown = function (e) {
      if (_this.props.disabled) {
        e.preventDefault();
      }
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Button.prototype.render = function render() {
    var _this2 = this;

    if (this.props.dropdown) {
      var _props = this.props,
          className = _props.className,
          style = _props.style,
          id = _props.id,
          label = _props.label,
          _children = _props.children;

      return React.createElement(
        Dropdown,
        { style: style, id: id || "dropdown-button" },
        React.createElement(
          Dropdown.Toggle,
          {
            className: className,
            id: id || "dropdown-button-toggle"
          },
          label
        ),
        React.createElement(
          Dropdown.Content,
          null,
          _children
        )
      );
    }

    var _getValidProps = getValidProps(this.props),
        children = _getValidProps.children,
        to = _getValidProps.to,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var ElementType = getElementType(Button, this.props);
    if (to) {
      props.href = props.href || to;
      props.target = props.target || "_blank";
      props.onClick = null;
    } else {
      props.onClick = this.handleClick;
    }

    return React.createElement(
      ElementType,
      props,
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          return _this2.renderOrphan(child, _extends({}, inherited, {
            onClick: _this2.chainFunction(child.props.onClick, function () {}),
            onKeyDown: _this2.chainFunction(child.props.onKeyDown, function () {})
          }));
        }
        return child;
      })
    );
  };

  return Button;
}(CoreComponent), _class.propTypes = getPropTypesA11y({
  dropdown: "bool"
}), _class.defaultProps = getPropDefaultsAutoId({
  renderAs: "button",
  uirole: ROLE.BUTTON,
  dropdown: false
}), _temp2);


export default Button;

==> style-o-matic-1.1.5.tgz: package/es/components/Button/Button.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import { isModifiedEvent, isLeftClickEvent, CoreComponent, setPropTypesA11y, setPropDefaultsAutoId, getValidProps, getElementType, ROLE } from "../../lib";
import Dropdown from "../Dropdown/Dropdown.js";
import "./Button.css";

var Button = (_temp2 = _class = function (_CoreComponent) {
  _inherits(Button, _CoreComponent);

  function Button() {
    var _temp, _this, _ret;

    _classCallCheck(this, Button);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.handleClick = function (e) {
      if (_this.props.disabled) {
        return;
      }
      if (_this.props.onClick) {
        _this.props.onClick(e);
      }
      if (isModifiedEvent(e) || !isLeftClickEvent(e)) {
        return;
      }
      if (e.defaultPrevented === true) {
        return;
      }
      e.preventDefault();
    }, _this.handleKeyDown = function (e) {
      if (_this.props.disabled) {
        e.preventDefault();
      }
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Button.prototype.render = function render() {
    var _this2 = this;

    if (this.props.dropdown) {
      var _props = this.props,
          className = _props.className,
          style = _props.style,
          id = _props.id,
          label = _props.label,
          _children = _props.children;

      return React.createElement(
        Dropdown,
        { style: style, id: id || "dropdown-button" },
        React.createElement(
          Dropdown.Toggle,
          {
            className: className,
            id: id || "dropdown-button-toggle"
          },
          label
        ),
        React.createElement(
          Dropdown.Content,
          null,
          _children
        )
      );
    }

    var _getValidProps = getValidProps(this.props),
        children = _getValidProps.children,
        to = _getValidProps.to,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var ElementType = getElementType(Button, this.props);
    if (to) {
      props.href = props.href || to;
      props.target = props.target || "_top";
      props.onClick = null;
    } else {
      props.onClick = this.handleClick;
    }

    return React.createElement(
      ElementType,
      props,
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          return _this2.renderOrphan(child, _extends({}, inherited, {
            onClick: _this2.chainFunction(child.props.onClick, function () {}),
            onKeyDown: _this2.chainFunction(child.props.onKeyDown, function () {})
          }));
        }
        return child;
      })
    );
  };

  return Button;
}(CoreComponent), _class.propTypes = setPropTypesA11y({
  dropdown: "bool"
}), _class.defaultProps = setPropDefaultsAutoId({
  renderAs: "button",
  uirole: ROLE.BUTTON,
  dropdown: false
}), _temp2);


export default Button;
